@@ -21,32 +21,6 @@ $(function(){
         }
     });
 
-    // Dynamically load menu on request.
-    $(document).on('click', '.dl-trigger', function(){
-        var $this = $(this);
-        var $explorer = $('#explorer');
-
-        $this.addClass('icon-spinner');
-
-        if(!$explorer.children().length){
-            $explorer.load(window.explorer_menu_url, function() {
-                $this.removeClass('icon-spinner');
-
-                $explorer.addClass('dl-menuwrapper').dlmenu({
-                    animationClasses : {
-                        classin : 'dl-animate-in-2',
-                        classout : 'dl-animate-out-2'
-                    }
-                });
-                $explorer.dlmenu('openMenu');          
-            });
-        }else{
-            $explorer.dlmenu('openMenu');          
-        }
-
-        return false;
-    });
-
     // Resize nav to fit height of window. This is an unimportant bell/whistle to make it look nice
     var fitNav = function(){
         $('.nav-wrapper').css('min-height',$(window).height());
