@@ -1,6 +1,10 @@
+import django
 from django.db import models
 from django.forms import Textarea
-from south.modelsinspector import add_introspection_rules
+
+if django.VERSION < (1, 7):
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], ["^wagtail\.wagtailcore\.fields\.RichTextField"])
 
 from wagtail.wagtailcore.rich_text import DbWhitelister, expand_db_html
 
@@ -29,5 +33,3 @@ class RichTextField(models.TextField):
         defaults = {'widget': RichTextArea}
         defaults.update(kwargs)
         return super(RichTextField, self).formfield(**defaults)
-
-add_introspection_rules([], ["^wagtail\.wagtailcore\.fields\.RichTextField"])
