@@ -6,6 +6,7 @@ from django.contrib.auth.decorators import permission_required
 
 from wagtail.wagtailadmin.modal_workflow import render_modal_workflow
 from wagtail.wagtailadmin.forms import SearchForm
+from wagtail.wagtailsearch.backends import get_search_backends
 
 from wagtail.wagtaildocs.models import Document
 from wagtail.wagtaildocs.forms import DocumentForm
@@ -96,6 +97,11 @@ def chooser_upload(request):
 
         if form.is_valid():
             form.save()
+
+            # Reindex the document to make sure all tags are indexed
+            for backend in get_search_backends():
+                backend.add(document)
+
             document_json = json.dumps({'id': document.id, 'title': document.title})
             return render_modal_workflow(
                 request, None, 'wagtaildocs/chooser/document_chosen.js',
