@@ -2,7 +2,7 @@ from django.shortcuts import get_object_or_404
 from django.core.servers.basehttp import FileWrapper
 from django.http import HttpResponse
 
-from wagtail.wagtaildocs.models import Document
+from wagtail.wagtaildocs.models import Document, document_served
 
 
 def serve(request, document_id, document_filename):
@@ -15,4 +15,7 @@ def serve(request, document_id, document_filename):
     response['Content-Disposition'] = 'attachment; filename=%s' % doc.filename
     response['Content-Length'] = doc.file.size
 
+    # Send document_served signal
+    document_served.send(sender=doc, request=request)
+
     return response
