@@ -64,12 +64,12 @@ class AbstractFormField(Orderable):
     choices = models.CharField(
         max_length=512,
         blank=True,
-        help_text=_('Comma seperated list of choices. Only applicable in checkboxes, radio and dropdown.')
+        help_text=_('Comma separated list of choices. Only applicable in checkboxes, radio and dropdown.')
     )
     default_value = models.CharField(
         max_length=255,
         blank=True,
-        help_text=_('Default value. Comma seperated values supported for checkboxes.')
+        help_text=_('Default value. Comma separated values supported for checkboxes.')
     )
     help_text = models.CharField(max_length=255, blank=True)
 
@@ -131,14 +131,8 @@ class AbstractForm(Page):
         return {}
 
     def process_form_submission(self, form):
-        # remove csrf_token from form.data
-        form_data = dict(
-            i for i in form.data.items()
-            if i[0] != 'csrfmiddlewaretoken'
-        )
-
         FormSubmission.objects.create(
-            form_data=json.dumps(form_data),
+            form_data=json.dumps(form.cleaned_data),
             page=self,
         )
 
